@@ -1,5 +1,4 @@
 /* Prefabricated message box implementation. */
-/* $Id: msgbox.c,v 1.95.4.3 2005/04/06 09:11:18 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -68,11 +67,11 @@ msg_box(struct terminal *term, struct memory_list *ml, enum msgbox_flags flags,
 
 	while (dlg->number_of_widgets < buttons + 1) {
 		unsigned char *label;
-		t_done_handler *done;
+		done_handler_T *done;
 		int bflags;
 
 		label = va_arg(ap, unsigned char *);
-		done = va_arg(ap, void *);
+		done = va_arg(ap, done_handler_T *);
 		bflags = va_arg(ap, int);
 
 		if (!label) {
@@ -94,16 +93,14 @@ msg_box(struct terminal *term, struct memory_list *ml, enum msgbox_flags flags,
 	return do_dialog(term, dlg, ml);
 }
 
-/* Do not inline this function, because with inline
- * elinks segfaults on Cygwin */
-static unsigned char *
+static inline unsigned char *
 msg_text_do(unsigned char *format, va_list ap)
 {
 	unsigned char *info;
 	int infolen, len;
 	va_list ap2;
 
-	VA_COPY(ap2, ap);
+	va_copy(ap2, ap);
 
 	infolen = vsnprintf(NULL, 0, format, ap2);
 	info = mem_alloc(infolen + 1);
@@ -163,6 +160,7 @@ refreshed_msg_box(struct terminal *term, enum msgbox_flags flags,
 		  unsigned char *(get_info)(struct terminal *, void *),
 		  void *data)
 {
+	/* [gettext_accelerator_context(refreshed_msg_box)] */
 	struct dialog_data *dlg_data;
 	unsigned char *info = get_info(term, data);
 
@@ -172,7 +170,7 @@ refreshed_msg_box(struct terminal *term, enum msgbox_flags flags,
 			   title, align,
 			   info,
 			   data, 1,
-			   N_("~OK"), NULL, B_ENTER | B_ESC);
+			   MSG_BOX_BUTTON(N_("~OK"), NULL, B_ENTER | B_ESC));
 
 	if (!dlg_data) return;
 
@@ -188,6 +186,10 @@ info_box(struct terminal *term, enum msgbox_flags flags,
 	 unsigned char *title, enum format_align align,
 	 unsigned char *text)
 {
-	return msg_box(term, NULL, flags, title, align, text,
-		       NULL, 1, N_("~OK"), NULL, B_ENTER | B_ESC);
+	/* [gettext_accelerator_context(info_box)] */
+	return msg_box(term, NULL, flags,
+		       title, align,
+		       text,
+		       NULL, 1,
+		       MSG_BOX_BUTTON(N_("~OK"), NULL, B_ENTER | B_ESC));
 }
