@@ -35,7 +35,7 @@
 #pragma alloca
 #else
 #ifndef HAVE_ALLOCA
-void *alloca(size_t);
+void *alloca(size_t size);
 #endif
 #endif
 #endif
@@ -110,11 +110,11 @@ extern int errno;
   /* Win32, OS/2, DOS */
 #define HAS_DEVICE(P) (isasciialpha((P)[0]) && (P)[1] == ':')
 #define IS_ABSOLUTE_PATH(P) (dir_sep((P)[0]) || HAS_DEVICE (P))
-#define IS_PATH_WITH_DIR(P) (strchr (P, '/') || strchr (P, '\\') || HAS_DEVICE (P))
+#define IS_PATH_WITH_DIR(P) (strchr ((const char *)(P), '/') || strchr ((const char *)(P), '\\') || HAS_DEVICE (P))
 #else
   /* Unix */
 #define IS_ABSOLUTE_PATH(P) dir_sep((P)[0])
-#define IS_PATH_WITH_DIR(P) strchr (P, '/')
+#define IS_PATH_WITH_DIR(P) strchr ((const char *)(P), '/')
 #endif
 
 /* XPG3 defines the result of `setlocale (category, NULL)' as:
@@ -187,13 +187,17 @@ transcmp(const void *p1, const void *p2)
 
 /* Name of the default domain used for gettext(3) prior any call to
    textdomain(3).  The default value for this is "messages".  */
-const unsigned char _nl_default_default_domain__[] = "messages";
+const char _AAA_nl_default_default_domain__[] = "messages";
+
+const unsigned char *_nl_default_default_domain__ = (const unsigned char *)_AAA_nl_default_default_domain__;
 
 /* Value used as the default domain for gettext(3).  */
-const unsigned char *_nl_current_default_domain__ = _nl_default_default_domain__;
+const unsigned char *_nl_current_default_domain__ = (const unsigned char *)_AAA_nl_default_default_domain__;
 
 /* Contains the default location of the message catalogs.  */
-const unsigned char _nl_default_dirname__[] = LOCALEDIR;
+const char _AAA_nl_default_dirname__[] = LOCALEDIR;
+
+const unsigned char *_nl_default_dirname__ = (const unsigned char *)_AAA_nl_default_dirname__;
 
 /* Contains application-specific LANGUAGE variation, taking precedence to the
  * $LANGUAGE environment variable.  */
@@ -240,7 +244,8 @@ struct block_list {
   do {									      \
     while (list != NULL) {						      \
       struct block_list *old = list;					      \
-      list = list->next;						      \
+      list = list->next;			      			\
+      free (old->address); 						\
       free (old);							      \
     }									      \
   } while (0)
@@ -400,7 +405,7 @@ dcigettext__(const unsigned char *domainname, const unsigned char *msgid1, const
 				: n == 1 ? (unsigned char *) msgid1 : (unsigned char *) msgid2);
 		}
 
-		stpcpy(stpcpy(strchr(dirname, '\0'), "/"), binding->dirname);
+		stpcpy(stpcpy(strchr((const char *)dirname, '\0'), "/"), binding->dirname);
 	}
 
 	/* Now determine the symbolic name of CATEGORY and its value.  */
@@ -780,7 +785,7 @@ plural_lookup(struct loaded_l10nfile *domain, unsigned long int n,
 	/* Skip INDEX strings at TRANSLATION.  */
 	p = translation;
 	while (indexx-- > 0) {
-		p = strchr(p, '\0');
+		p = strchr((const char *)p, '\0');
 
 		/* And skip over the NUL byte.  */
 		p++;
