@@ -554,6 +554,10 @@ connect_socket(struct socket *csocket, struct connection_state state)
 	 * about such a connection attempt.
 	 * XXX: Unify with @local_only handling? --pasky */
 	int silent_fail = 0;
+	unsigned char *bind_address = get_cmd_opt_str("bind-address");
+	unsigned char *bind_address_ipv6 = get_cmd_opt_str("bind-address-ipv6");
+	int to_bind = (bind_address && *bind_address);
+	int to_bind_ipv6 = (bind_address_ipv6 && *bind_address_ipv6);
 
 	csocket->ops->set_state(csocket, state);
 
@@ -624,6 +628,45 @@ connect_socket(struct socket *csocket, struct connection_state state)
 			close(sock);
 			continue;
 		}
+
+#ifdef HAVE_INET_PTON
+		if (pf == PF_INET && to_bind) {
+			struct sockaddr_in sa;
+			int res;
+
+			memset(&sa, 0, sizeof sa);
+			sa.sin_family = AF_INET;
+			inet_pton(AF_INET, bind_address, &(sa.sin_addr));
+			sa.sin_port = htons(0);
+			res = bind(sock, (struct sockaddr *)(void *)&sa, sizeof sa);
+
+			if (res < 0) {
+				if (errno && !saved_errno) saved_errno = errno;
+				close(sock);
+				continue;
+			}
+		}
+#ifdef CONFIG_IPV6
+		if (pf == PF_INET6 && to_bind_ipv6) {
+			struct sockaddr_in6 sa;
+			int res;
+
+			memset(&sa, 0, sizeof sa);
+			sa.sin6_family = AF_INET6;
+			inet_pton(AF_INET6, bind_address_ipv6, &(sa.sin6_addr));
+			sa.sin6_port = htons(0);
+			res = bind(sock, (struct sockaddr *)(void *)&sa, sizeof sa);
+
+			if (res < 0) {
+				if (errno && !saved_errno) saved_errno = errno;
+				close(sock);
+				continue;
+			}
+		}
+#endif
+#endif
+
+
 		csocket->fd = sock;
 
 #ifdef CONFIG_IPV6
