@@ -26,7 +26,7 @@
 
 
 struct bittorrent_download_info {
-	struct list_head labels;	/* -> struct string_list_item */
+	LIST_OF(struct string_list_item) labels;
 	unsigned char *name;
 	int *selection;
 	size_t size;
@@ -150,7 +150,7 @@ add_bittorrent_meta_to_string(struct string *msg, struct bittorrent_meta *meta,
 		add_format_to_string(msg, "\n%s: ",
 			_("Creation date", term));
 		add_date_to_string(msg,
-			get_opt_str("ui.date_format"),
+			get_opt_str("ui.date_format", NULL),
 			&meta->creation_date);
 	}
 #endif
@@ -479,7 +479,7 @@ draw_bittorrent_piece_progress(struct download *download, struct terminal *term,
 		int remainder	    = width % bittorrent->meta.pieces;
 
 		for (piece = 0; piece < bittorrent->meta.pieces; piece++) {
-			struct box piecebox;
+			struct el_box piecebox;
 
 			set_box(&piecebox, x, y, chars_per_piece + !!remainder, 1);
 
@@ -531,7 +531,7 @@ draw_bittorrent_piece_progress(struct download *download, struct terminal *term,
 		}
 	}
 
-	if (download->state == S_RESUME) {
+	if (is_in_state(download->state, S_RESUME)) {
 		static unsigned char s[] = "????"; /* Reduce or enlarge at will. */
 		unsigned int slen = 0;
 		int max = int_min(sizeof(s), width) - 1;
@@ -574,7 +574,12 @@ bittorrent_message_dialog(struct session *ses, void *data)
 
 	uristring = get_uri_string(message->uri, URI_PUBLIC);
 	if (uristring) {
-		decode_uri_for_display(uristring);
+#ifdef CONFIG_UTF8
+		if (ses->tab->term->utf8_cp)
+			decode_uri(uristring);
+		else
+#endif /* CONFIG_UTF8 */
+			decode_uri_for_display(uristring);
 		add_format_to_string(&string,
 			_("Unable to retrieve %s", ses->tab->term),
 			uristring);
@@ -582,9 +587,10 @@ bittorrent_message_dialog(struct session *ses, void *data)
 		add_to_string(&string, ":\n\n");
 	}
 
-	if (message->state != S_OK) {
+	if (!is_in_state(message->state, S_OK)) {
 		add_format_to_string(&string, "%s: %s",
-			get_state_message(S_BITTORRENT_TRACKER, ses->tab->term),
+			get_state_message(connection_state(S_BITTORRENT_TRACKER),
+					  ses->tab->term),
 			get_state_message(message->state, ses->tab->term));
 	} else {
 		add_to_string(&string, message->string);
@@ -610,8 +616,11 @@ abort_bittorrent_download_query(struct dialog_data *dlg_data)
 	done_bittorrent_download_info(info);
 }
 
-/* The download button handler. Basicly it redirects <uri> to bittorrent:<uri>
- * and starts displaying the download. */
+/** The download button handler. Basicly it redirects \<uri> to
+ * bittorrent:\<uri> and starts displaying the download.
+ *
+ * bittorrent_query_callback() passes this function as a
+ * ::widget_handler_T to add_dlg_button().  */
 static widget_handler_status_T
 bittorrent_download(struct dialog_data *dlg_data, struct widget_data *widget_data)
 {
@@ -669,7 +678,7 @@ bittorrent_download(struct dialog_data *dlg_data, struct widget_data *widget_dat
 
 /* Show the protocol header. */
 /* XXX: Code duplication with session/download.h */
-widget_handler_status_T
+static widget_handler_status_T
 tp_show_header(struct dialog_data *dlg_data, struct widget_data *widget_data)
 {
 	struct type_query *type_query = widget_data->widget->data;
@@ -679,11 +688,15 @@ tp_show_header(struct dialog_data *dlg_data, struct widget_data *widget_data)
 	return EVENT_PROCESSED;
 }
 
-/* Build a dialog querying the user on how to handle a .torrent file. */
+/** Build a dialog querying the user on how to handle a .torrent file.
+ *
+ * query_bittorrent_dialog() passes this function as a
+ * ::bittorrent_fetch_callback_T to init_bittorrent_fetch().  */
 static void
-bittorrent_query_callback(void *data, enum connection_state state,
-			    struct string *response)
+bittorrent_query_callback(void *data, struct connection_state state,
+			  struct bittorrent_const_string *response)
 {
+	/* [gettext_accelerator_context(.bittorrent_query_callback)] */
 	struct type_query *type_query = data;
 	struct string filename;
 	unsigned char *text;
@@ -699,7 +712,7 @@ bittorrent_query_callback(void *data, enum connection_state state,
 	struct string msg;
 	int files;
 
-	if (state != S_OK)
+	if (!is_in_state(state, S_OK))
 		return;
 
 	/* This should never happen, since setup_download_handler() should make
@@ -718,7 +731,12 @@ bittorrent_query_callback(void *data, enum connection_state state,
 
 		/* Let's make the filename pretty for display & save */
 		/* TODO: The filename can be the empty string here. See bug 396. */
-		decode_uri_string_for_display(&filename);
+#ifdef CONFIG_UTF8
+		if (term->utf8_cp)
+			decode_uri_string(&filename);
+		else
+#endif /* CONFIG_UTF8 */
+			decode_uri_string_for_display(&filename);
 	}
 
 	add_format_to_string(&msg,
@@ -728,7 +746,8 @@ bittorrent_query_callback(void *data, enum connection_state state,
 	done_string(&filename);
 
 	if (parse_bittorrent_metafile(&meta, response) != BITTORRENT_STATE_OK) {
-		print_error_dialog(type_query->ses, S_BITTORRENT_METAINFO,
+		print_error_dialog(type_query->ses,
+				   connection_state(S_BITTORRENT_METAINFO),
 				   type_query->uri, PRI_CANCEL);
 		tp_cancel(type_query);
 		done_string(&msg);
@@ -803,7 +822,7 @@ bittorrent_query_callback(void *data, enum connection_state state,
 
 	add_dlg_end(dlg, widgets);
 
-	ml = getml(dlg, NULL);
+	ml = getml(dlg, (void *) NULL);
 	if (!ml) {
 		/* XXX: Assume that the allocated @external_handler will be
 		 * freed when releasing the @type_query. */
