@@ -261,7 +261,7 @@ setraw(struct itrm *itrm, int save_orig)
 	elinks_cfmakeraw(&t);
 	t.c_lflag |= ISIG;
 #ifdef TOSTOP
-	t.c_lflag |= TOSTOP;
+	t.c_lflag |= get_opt_bool("ui.tostop", NULL) ? TOSTOP : 0;
 #endif
 	t.c_oflag |= OPOST;
 	if (tcsetattr(itrm->in.ctl, TCSANOW, &t)) return -1;
